package org.apache.bcel.classfile;

import java.io.DataOutputStream;
import java.io.IOException;
import java.io.DataInput;

public final class LineNumber implements Cloneable, Node
{
    private short startPc;
    private short lineNumber;
    
    LineNumber(final DataInput file) throws IOException {
        this(file.readUnsignedShort(), file.readUnsignedShort());
    }
    
    public LineNumber(final int startPc, final int lineNumber) {
        this.startPc = (short)startPc;
        this.lineNumber = (short)lineNumber;
    }
    
    public LineNumber(final LineNumber c) {
        this(c.getStartPC(), c.getLineNumber());
    }
    
    @Override
    public void accept(final Visitor v) {
        v.visitLineNumber(this);
    }
    
    public LineNumber copy() {
        try {
            return (LineNumber)this.clone();
        }
        catch (final CloneNotSupportedException ex) {
            return null;
        }
    }
    
    public void dump(final DataOutputStream file) throws IOException {
        file.writeShort(this.startPc);
        file.writeShort(this.lineNumber);
    }
    
    public int getLineNumber() {
        return this.lineNumber & 0xFFFF;
    }
    
    public int getStartPC() {
        return this.startPc & 0xFFFF;
    }
    
    public void setLineNumber(final int lineNumber) {
        this.lineNumber = (short)lineNumber;
    }
    
    public void setStartPC(final int startPc) {
        this.startPc = (short)startPc;
    }
    
    @Override
    public String toString() {
        return "LineNumber(" + this.getStartPC() + ", " + this.getLineNumber() + ")";
    }
}
